@@ -1,16 +1,13 @@
-import ed25519
+from nacl.signing import SigningKey
 import base64
 import hashlib
 
-def hash_and_sign(cmd_json, pub_key, priv_key):
+def hash_and_sign(cmd_json, priv_key):
   # Turn the json into a byte string
   cmd_data = bytes(cmd_json, encoding="utf8")
 
   # Create the signature
-  sk = ed25519.keys.SigningKey(bytes(priv_key, encoding="utf8"))
-  signing_key = priv_key + pub_key
-  sk.vk_s = bytes.fromhex(pub_key)
-  sk.sk_s = bytes.fromhex(signing_key)
+  sk = SigningKey(bytes.fromhex(priv_key))
 
   # Create the hash code
   hash_bytes = blake2b(cmd_data)
